/*
 * Animation.cpp
 *
 *  Created on: Oct 2, 2008
 *      Author: Santi
 */

#ifdef KITSCHY_DEBUG_MEMORY
#include "debug_memorymanager.h"
#endif

#ifdef _WIN32
#include <windows.h>
#endif

#include "Animation.h"

Animation::Animation(bool looped) {
	m_looped = looped;
	m_timmer = 0;
	m_SFXM = 0;
	m_currentFrame = 0;
}

Animation::Animation(bool looped, SFXManager *SFXM) {
	m_looped = looped;
	m_timmer = 0;
	m_SFXM = SFXM;
	m_currentFrame = 0;
}

Animation::~Animation() {
}

void Animation::addFrame(GLTile *frame,int time)
{
	m_frames.Add(new AnimationFrame(frame,time,0,0));
}

void Animation::addFrame(GLTile *frame,int time,char *sfx,int volume)
{
	m_frames.Add(new AnimationFrame(frame,time,sfx,volume));
}

void Animation::reset()
{
	m_currentFrame = 0;
	m_timmer = 0;
}

GLTile *Animation::cycle()
{
	AnimationFrame *current = m_frames[m_currentFrame];

	if (current==0) {
		if (m_looped) {
			reset();
			current = (m_currentFrame==-1 ? 0:m_frames[m_currentFrame]);		
		}
	}

	if (current!=0) {
		if (m_timmer==0 && current->m_sfx!=0) {
			m_SFXM->SFX_play(current->m_sfx, current->m_volume);
		}
		m_timmer++;
		if (m_timmer>=current->m_time) {
			m_currentFrame++;
			m_timmer = 0;
		}
	}

	return current->m_tile;
}

void Animation::smoothTransition(Animation *a) {
	if (a!=0 &&
		a->m_looped==m_looped &&
		a->m_frames.Length() == m_frames.Length()) {
		if (a->m_currentFrame>=0 && a->m_currentFrame<a->m_frames.Length()) {
			m_currentFrame = a->m_currentFrame;
			m_timmer = a->m_timmer;
		} else {
			reset();
		}
	}
}
