#ifndef _KNIGHTMARE_OBJECT
#define _KNIGHTMARE_OBJECT

#include "Symbol.h"
#include "SFXManager.h"
#include "Animation.h"

// #include "Knightmare.h"

class KObject
{
    public:
        KObject(int x, int y, int sfx_volume);
        virtual ~KObject();

        virtual bool cycle(List<class VirtualController> *vcl, class Knightmare *game, class GLTManager *GLTM, SFXManager *SFXM);
        virtual void draw(float angle,GLTManager *GLTM);
        virtual void draw(float angle,int x_offset,int y_offset,GLTManager *GLTM);	// The angle represents the camera angle

        virtual bool is_a(Symbol *c);
        virtual bool is_a(char *c);

        float get_x(void)
        {
            return m_x;
        };
        float get_y(void)
        {
            return m_y;
        };
        void set_x(float x)
        {
            m_x = x;
        };
        void set_y(float y)
        {
            m_y = y;
        };
		void set_layer(int l) {
			m_layer = l;
		};
		int get_layer() {
			return m_layer;
		};

        int get_state(void)
        {
            return m_state;
        };
        void set_state(int state)
        {
            m_state = state;
        };

        virtual bool collision(KObject *o);
        virtual bool collision(int xoffs, int yoffs, KObject *o);
        virtual bool collision(class GLTile *t, int x, int y);
        virtual bool collision(class C2DCMC *t, int x, int y);
        virtual bool collision(int xoffs, int yoffs, GLTile *t, int x, int y);

        Symbol *get_class(void)
        {
            return m_class;
        };


        GLTile *get_last_tile_used(void)
        {
            return m_last_tile_used;
        };

        int get_distance(KObject *player);
        int get_angle(KObject *player);

    protected:

    	bool m_keep_angle;	// objects for which m_keep_angle = true, do not rotate with the camera
        int m_sfx_volume;
        int m_n_states;
        int m_state;
        int m_state_cycle;
        float m_x, m_y;
        int m_layer;
        Symbol *m_class;
        GLTile *m_last_tile_used; // used to ease collision detection

        Animation *m_current_animation;
    	Animation **m_state_animations;
};

#endif

